==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/marketplace/messages/ru/base.php <==
<?php

return [
    '
Module successfully disabled!
' => '
Модуль успешно отключен!
',
    '
Module successfully enabled!
' => '
Модуль успешно подключен!
',
    '--- Disable module: {moduleId} ---

' => '--- Отключение модуля: {moduleId} ---

',
    '--- Enable module: {moduleId} ---

' => '--- Включение модуля: {moduleId} ---

',
    '<strong>Activate</strong> your Professional Edition' => '<strong>Активируйте</strong> свою Профессиональную версию',
    'Add purchased module by licence key' => 'Добавить ключ для приобретённого модуля',
    'All {moduleId} module content will be deleted. Continue?' => 'Весть контент модуля {moduleId} будет удалён. Продолжить?',
    'Buy (%price%)' => 'Купить (%price%)',
    'Could not extract module!' => 'Не удалось извлечь модуль!',
    'Could not remove old module path!' => 'Не удалось удалить старый путь к модулю!',
    'Could not update licence. Error: ' => 'Не удалось обновить лицензию. Ошибка:',
    'Download of module failed!' => 'Не удалось загрузить модуль!',
    'Edit licence' => 'Редактировать лицензию',
    'Install' => 'Установить',
    'Installed' => 'Установленные',
    'Installing module...' => 'Установить модуль...',
    'Latest version:' => 'Последняя версия:',
    'Licence Key:' => 'Лицензионный Ключ:',
    'Licence key' => 'Ключ лицензии',
    'Licenced for max. {number} users.' => 'Лицензия на максимум {число} пользователей.',
    'Licenced to:' => 'Лицензировано для:',
    'Marketplace' => 'Маркет',
    'Max. users:' => 'Максимальное количество пользователей:',
    'Module directory %modulePath% is not writeable!' => 'Папка модуля %modulePath% запрещает запись в неё!',
    'Module download failed! (%error%)' => 'Не удалось загрузить модуль! (%error%)',
    'Module not found or activated!
' => 'Модуль не найден или уже активирован!
',
    'Module not found!
' => 'Модуль не найден!
',
    'More info' => 'Подробнее',
    'No compatible module version found!' => 'Совместимых версий модуля не найдено!',
    'No license key? Find out more about the {pro} or contact us.' => 'Нет лицензионного ключа? Узнайте больше о {pro} или свяжитесь с нами напрямую.',
    'No purchased modules found!' => 'Приобретённых модулей не найдено!',
    'Ok' => 'Ок',
    'Professional Edition is activated!' => 'Профессиональная Версия активирована!',
    'Register' => 'Регистрация',
    'Remove licence key' => 'Удалить лицензионный ключ',
    'Save and update' => 'Сохранить и обновить',
    'Third-party' => 'Сторонние разработчики',
    'Third-party disclaimer' => 'Отказ от ответственности за продукты сторонних разработчиков',
    'Update' => 'Обновить',
    'Upgrade to Professional Edition' => 'Обновление до Профессиональной Версии',
    'Version:' => 'Версия:',
    '
No active Professional Edition license found!
' => '',
    '
PROFESSIONAL EDITION
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Add Licence Key' => '',
    'All' => '',
    'Available Updates' => '',
    'Buy' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not connect to licence server!' => '',
    'Featured' => '',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => '',
    'Invalid module licence key!
' => '',
    'Learn more' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'New' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'Tags' => '',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => '',
    'Third-party Modules are not covered by Professional Edition agreements.' => '',
    'This Module was developed by a third-party.' => '',
    'Update all' => '',
    'Your HumHub installation is up to date!' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/marketplace/messages/ru/base.php <==
<?php

return [
    '
Module successfully disabled!
' => '
Модуль успешно отключен!
',
    '
Module successfully enabled!
' => '
Модуль успешно подключен!
',
    '--- Disable module: {moduleId} ---

' => '--- Отключение модуля: {moduleId} ---

',
    '--- Enable module: {moduleId} ---

' => '--- Включение модуля: {moduleId} ---

',
    '<strong>Activate</strong> your Professional Edition' => '<strong>Активируйте</strong> свою Профессиональную версию',
    'Activate' => 'Активировать',
    'Activated' => 'Включен',
    'Add Licence Key' => 'Добавить лицензионный ключ',
    'Add purchased module by licence key' => 'Добавить ключ для приобретённого модуля',
    'All' => 'Все',
    'All {moduleId} module content will be deleted. Continue?' => 'Весть контент модуля {moduleId} будет удалён. Продолжить?',
    'Buy (%price%)' => 'Купить (%price%)',
    'Configure' => 'Настройки',
    'Could not extract module!' => 'Не удалось извлечь модуль!',
    'Could not find requested module!' => 'Не удалось найти запрошенный модуль!',
    'Could not remove old module path!' => 'Не удалось удалить старый путь к модулю!',
    'Could not update licence. Error: ' => 'Не удалось обновить лицензию. Ошибка:',
    'Download of module failed!' => 'Не удалось загрузить модуль!',
    'Edit licence' => 'Редактировать лицензию',
    'General Settings' => 'Общие настройки',
    'Information' => 'Информация',
    'Install' => 'Установить',
    'Installed' => 'Установленные',
    'Latest version:' => 'Последняя версия:',
    'Licence Key:' => 'Лицензионный Ключ:',
    'Licence key' => 'Ключ лицензии',
    'Licenced for max. {number} users.' => 'Лицензия на максимум {число} пользователей.',
    'Licenced to:' => 'Лицензировано для:',
    'Marketplace' => 'Маркет',
    'Max. users:' => 'Максимальное количество пользователей:',
    'Module directory %modulePath% is not writeable!' => 'Папка модуля %modulePath% запрещает запись в неё!',
    'Module download failed! (%error%)' => 'Не удалось загрузить модуль! (%error%)',
    'Module not found or activated!
' => 'Модуль не найден или уже активирован!
',
    'Module not found!
' => 'Модуль не найден!
',
    'More info' => 'Подробнее',
    'New' => 'Новое',
    'No compatible module version found!' => 'Совместимых версий модуля не найдено!',
    'No license key? Find out more about the {pro} or contact us.' => 'Нет лицензионного ключа? Узнайте больше о {pro} или свяжитесь с нами напрямую.',
    'No modules installed yet. Install some to enhance the functionality!' => 'Ни один из модулей не установлен. Установите необходимые модули для расширения функциональности.',
    'No purchased modules found!' => 'Приобретённых модулей не найдено!',
    'Ok' => 'Ок',
    'Professional Edition is activated!' => 'Профессиональная Версия активирована!',
    'Register' => 'Регистрация',
    'Remove licence key' => 'Удалить лицензионный ключ',
    'Save and update' => 'Сохранить и обновить',
    'Search' => 'Поиск',
    'Search...' => 'Поиск...',
    'Settings' => 'Настройки',
    'Tags' => 'Теги',
    'Third-party' => 'Сторонние разработчики',
    'Third-party disclaimer' => 'Отказ от ответственности за продукты сторонних разработчиков',
    'Update' => 'Обновить',
    'Upgrade to Professional Edition' => 'Обновление до Профессиональной Версии',
    'Version:' => 'Версия:',
    '
No active Professional Edition license found!
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Activate now' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Buy' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not connect to licence server!' => '',
    'Could not find the requested module!' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'Great!' => '',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => '',
    'Invalid module licence key!' => '',
    'Invalid module licence key!
' => '',
    'Learn more' => '',
    'License not found or expired. Please contact the module publisher.' => '',
    'Marketplace is disabled.' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>activated</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module configuration' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'No modules found.' => '',
    'Official' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => '',
    'Third-party Modules are not covered by Professional Edition agreements.' => '',
    'This Module was developed by a third-party.' => '',
    'Try other keywords or remove filters.' => '',
    'Uninstalled' => '',
    'Update all' => '',
    'Update successful' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => '',
    'Well done! You have successful installed an activated the module!' => '',
    'Would you like to jump straight to it?' => '',
    'Your HumHub installation is up to date!' => '',
];
